@@ -54,22 +54,31 @@ build()
 
 cov_prepare()
 {
+    make clean
+
     rm -fr ${TMP_INSTALL}
     make -f Makefile.git 
     exit_on_failure $? "make -f Makefile.git"
 
-    ./configure --prefix=${TMP_INST}  --enable-unittest
+    ./configure --disable-shared-test  --disable-shared --enable-unittest  --prefix=${TMP_INST} 
     exit_on_failure $? "configure"
 }
 
 cov()
 {
+    export COV_FLAGS=" -fprofile-arcs -ftest-coverage -g "
     make clean
     exit_on_failure $? "make clean"
 
-    make coverage
+    export CFLAGS="$COV_FLAGS" 
+    export CXXFLAGS="$COV_FLAGS" 
+    export CFLAGS="$COV_FLAGS -ldl" 
+#    make CFLAGS="$COV_FLAGS" CXXFLAGS="$COV_FLAGS" CFLAGS="$COV_FLAGS -ldl"  coverage
+    make LDFLAGS=" -fprofile-arcs -ftest-coverage -g"   CFLAGS=" -fprofile-arcs -ftest-coverage -g"   V=1   LDFLAGS=" -fprofile-arcs -ftest-coverage -g"   CXXFLAGS=" -fprofile-arcs -ftest-coverage -g"   coverage
     exit_on_failure $? "make coverage"
-
+    export CFLAGS="" 
+    export CXXFLAGS="" 
+    export CFLAGS="" 
 }
 
 check()
