@@ -56,6 +56,7 @@ static arduino_pin arduino_analog_pins[NR_OF_ANALOG_PINS];
 #define PIN_OUT_OF_RANGE(pin)          (pin<0 || pin> NR_OF_ANALOG_PINS)
 #define get_analog_pin_mode(pin)      (arduino_analog_pins[pin].mode) 
 #define set_analog_pin_mode(pin,mode)  arduino_analog_pins[pin].mode=mode; 
+
 #define get_analog_pin_val(pin)       (arduino_analog_pins[pin].val) 
 #define set_analog_pin_val(pin,val)    arduino_analog_pins[pin].val=(val%1024);
 
@@ -82,13 +83,6 @@ analogRead(uint8_t pin)
   return get_analog_pin_val(pin);
 }
 
-void analogWrite(uint8_t pin, unsigned int val)
-{
-  set_analog_pin_val(pin,val)
-
-  comm_analog_write_outpin(pin,val);
-}
-
 /*
  *
  * Callback used to update in_pins
@@ -134,3 +128,11 @@ anaout_callback(uint8_t pin)
 
   return get_analog_pin_val(pin);
 }
+
+void analogWrite(uint8_t pin, int val)
+{
+  set_analog_pin_val(pin,val);
+
+  comm_analog_write_outpin(pin,val);
+}
+
