@@ -19,8 +19,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-export LD_LIBRARY_PATH=/opt/searduino/lib
-export PYTHONPATH=/opt/searduino/lib
+export LD_LIBRARY_PATH=/opt/lib
+export PYTHONPATH=/opt/lib
 
-/opt/searduino/bin/pardon.py $*
+/opt/bin/pardon.py $*
 
